@@ -191,8 +191,6 @@ mod bit_vec_06;
 mod chrono_04;
 #[cfg(feature = "with-eui48-0_4")]
 mod eui48_04;
-#[cfg(feature = "with-geo-types-0_4")]
-mod geo_types_04;
 #[cfg(feature = "with-geo-types-0_6")]
 mod geo_types_06;
 #[cfg(feature = "with-serde_json-1")]
@@ -951,3 +949,36 @@ fn downcast(len: usize) -> Result<i32, Box<dyn Error + Sync + Send>> {
         Ok(len as i32)
     }
 }
+
+mod sealed {
+    pub trait Sealed {}
+}
+
+/// A trait used by clients to abstract over `&dyn ToSql` and `T: ToSql`.
+///
+/// This cannot be implemented outside of this crate.
+pub trait BorrowToSql: sealed::Sealed {
+    /// Returns a reference to `self` as a `ToSql` trait object.
+    fn borrow_to_sql(&self) -> &dyn ToSql;
+}
+
+impl sealed::Sealed for &dyn ToSql {}
+
+impl BorrowToSql for &dyn ToSql {
+    #[inline]
+    fn borrow_to_sql(&self) -> &dyn ToSql {
+        *self
+    }
+}
+
+impl<T> sealed::Sealed for T where T: ToSql {}
+
+impl<T> BorrowToSql for T
+where
+    T: ToSql,
+{
+    #[inline]
+    fn borrow_to_sql(&self) -> &dyn ToSql {
+        self
+    }
+}
